@@ -17,7 +17,8 @@ from django.template.loader import render_to_string
 from django.utils.safestring import mark_safe
 
 from checklists.models import Map, Filter, Location, Species, \
-    Checklist, Activity, Protocol, Method, Entry, Detail, Age, Sex, Observer
+    Checklist, Activity, Protocol, Method, Entry, Detail, Age, Sex, Observer, \
+    set_current_user, clear_current_user
 
 
 logger = logging.getLogger(__name__)
@@ -398,6 +399,7 @@ class Command(BaseCommand):
         paths = find_files(directory, 'json')
 
         filters = load_filters()
+        set_current_user('load_checklists')
 
         for path in paths:
             try:
@@ -421,6 +423,8 @@ class Command(BaseCommand):
             'errors': failed,
         })
 
+        clear_current_user()
+
         if settings.DEBUG:
             filename = os.path.join(directory, 'load_checklists_report.txt')
             with open(filename, 'wb') as fp:
