@@ -24,14 +24,33 @@ from django.contrib.auth.models import User
 from django.contrib.contenttypes.generic import GenericForeignKey
 from django.core.validators import MinValueValidator
 from django.db.models import Model, BooleanField, IntegerField, \
-    CharField, TextField, DateField, TimeField, ForeignKey, OneToOneField, \
-    ManyToManyField, PROTECT, SET_NULL, PositiveIntegerField
+    CharField, TextField, DateField, TimeField, DateTimeField, \
+    ForeignKey, OneToOneField, ManyToManyField, PROTECT, SET_NULL, \
+    PositiveIntegerField
 from django.template.defaultfilters import slugify
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.contenttypes.models import ContentType
 
 from transmeta import TransMeta
 
+from threading import local
+
+
+_thread_locals = local()
+
+
+def set_current_user(user):
+    _thread_locals.user = user
+
+
+def get_current_user():
+    return getattr(_thread_locals, 'user', '')
+
+
+def clear_current_user():
+    if hasattr(_thread_locals, 'user'):
+        del _thread_locals.user
+
 
 class ChecklistsModel(Model):
     """Base class for the Checklists model."""
@@ -39,10 +58,20 @@ class ChecklistsModel(Model):
     class Meta:
         abstract = True
 
+    created_by = CharField(max_length=50, blank=True)
+    created_on = DateTimeField(auto_now_add=True)
+    modified_by = CharField(max_length=50, blank=True)
+    modified_on = DateTimeField(auto_now=True)
+
     def save(self, force_insert=False, force_update=False, **kwargs):
         """Validate a model object on save."""
         if not (force_insert or force_update):
             self.full_clean()
+
+        self.modified_by = get_current_user()
+        if not self.pk:
+            self.created_by = self.modified_by
+
         super(ChecklistsModel, self)\
             .save(force_insert, force_update, **kwargs)
 
