@@ -5,10 +5,12 @@ table is not cleared first in case the script is run inadvertently on an
 existing database.
 """
 from checklists import get_data_path
-from checklists.models import Age
+from checklists.models import Age, set_current_user, clear_current_user
 
 from utils import create_objects, get_object_data
 
 
 def run():
+    set_current_user('load_ages')
     create_objects(Age, get_object_data(get_data_path('age'), 'slug'))
+    clear_current_user()
